@@ -538,6 +538,7 @@ add_bwrap (GPtrArray   *array,
   add_args (array,
 	    "bwrap",
 	    "--ro-bind", "/usr", "/usr",
+	    "--ro-bind", "/etc/ld.so.cache", "/etc/ld.so.cache",
 	    NULL);
 
   /* These directories might be symlinks into /usr/... */
@@ -564,6 +565,10 @@ add_bwrap (GPtrArray   *array,
         }
     }
 
+  /* fontconfig cache if necessary */
+  if (!g_str_has_prefix (FONTCONFIG_CACHE_PATH, "/usr/"))
+    add_args (array, "--ro-bind-try", FONTCONFIG_CACHE_PATH, FONTCONFIG_CACHE_PATH, NULL);
+
   add_args (array,
 	    "--proc", "/proc",
 	    "--dev", "/dev",
